package com.semarchy.mdm.client.samples;

import java.util.Locale;

import com.semarchy.mdm.client.IDataEditionConnection;
import com.semarchy.mdm.client.IMDMConnection;
import com.semarchy.mdm.client.MDMConnectionFactory;
import com.semarchy.mdm.runtime.activity.ActivityPriority;
import com.semarchy.mdm.runtime.activity.IActivityService;
import com.semarchy.mdm.runtime.activity.IActivityService.ITaskCompletionResult;
import com.semarchy.mdm.runtime.activity.IActivityTask;
import com.semarchy.mdm.runtime.data.IDataAccessService;
import com.semarchy.mdm.runtime.data.IEntityRow;
import com.semarchy.mdm.runtime.model.logical.IApplication;
import com.semarchy.mdm.runtime.model.logical.IDataEntryWorkflow;
import com.semarchy.mdm.runtime.model.logical.IEntity;
import com.semarchy.mdm.runtime.model.logical.IHumanTask;
import com.semarchy.mdm.runtime.model.logical.IModel;

public class Sample4_CreateEmployeeDataEntryWorkflow {

	public static void main(String[] args) {
		IMDMConnection conn = MDMConnectionFactory.connect(
				SamplesConstants.SEMARCHY_URL, SamplesConstants.USERNAME,
				SamplesConstants.PASSWORD);

		IDataEditionConnection dataEditionConnection = conn
				.createDataEditionConnection(SamplesConstants.GS_DATAEDITION);
		
		IModel logicalModel = dataEditionConnection.getLogicalModel();
		IApplication demoApplication = logicalModel.getApplication(SamplesConstants.GS_DEMO_APP);
		
		
		IDataEntryWorkflow employeeCreationWF = demoApplication.getDataEntryWorkflow("EmployeesCreationProcess");		
		IActivityService activityService = dataEditionConnection
				.getActivityService();

		IDataAccessService dataService = dataEditionConnection
				.getDataAccessService();

		// Start a DataEntry Activity
		IHumanTask startWFTask = employeeCreationWF
				.getTask("CreateOrModifyEmployeeData");
		IActivityTask createEmployeeTask = activityService.startActivity(
				startWFTask,
				"Client API Samples (Sample4_CreateEmployeeDataEntryWorkflow)",
				"John Doe just join the company lets create it's user",
				ActivityPriority.HIGH, true, false, null);

		// Create a new record for John Doe
		IEntity employeeEntity = logicalModel.getEntity("Employee");
		IEntityRow newEmployee = dataService.newRow(createEmployeeTask,
				employeeEntity);
		newEmployee.setValue("FirstName", "John");
		newEmployee.setValue("LastName", "Doe");
		newEmployee.setValue("Gender", "M");
		newEmployee.setValue("PhoneNumber", "007");
		newEmployee.setValue("EmailAddress", "john@doe.com");
		newEmployee.setValue("FID_CostCenter", 120);

		// Persist the created Row
		dataService.persistRow(createEmployeeTask.getTaskUUID(), newEmployee);
		
		// After persist newEmployee record is updated with generated ID
		System.out.println("New Employee ID:"+ newEmployee.getValue("Gold_EmployeeNumber"));

		// Submit the changes to the integration process
		ITaskCompletionResult result = activityService.completeTask(createEmployeeTask.getTaskUUID(), startWFTask.getSubmitTransition().getName(),				
				"OK. I'm done creating John Doe.", null);

		if (result.isCompleted()) {
			System.out.println("Employee Creation submitted in batch number "
					+ result.getSubmittedBatchID());	
		} else {
			System.err.println("Task not completed transition failed: "
					+ result.getTransitionValidationReport().getSummary(Locale.getDefault()));
		}
		
	}
}
